package java.awt.font;

import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;

public class FontRenderContext
{
    private transient AffineTransform tx;
    private transient Object aaHintValue;
    private transient Object fmHintValue;
    private transient boolean defaulting;
    
    protected FontRenderContext() {
        this.aaHintValue = RenderingHints.VALUE_TEXT_ANTIALIAS_DEFAULT;
        this.fmHintValue = RenderingHints.VALUE_FRACTIONALMETRICS_DEFAULT;
        this.defaulting = true;
    }
    
    public FontRenderContext(AffineTransform tx, boolean b, boolean b2) {
        if (tx != null && !tx.isIdentity()) {
            this.tx = new AffineTransform(tx);
        }
        if (b) {
            this.aaHintValue = RenderingHints.VALUE_TEXT_ANTIALIAS_ON;
        }
        else {
            this.aaHintValue = RenderingHints.VALUE_TEXT_ANTIALIAS_OFF;
        }
        if (b2) {
            this.fmHintValue = RenderingHints.VALUE_FRACTIONALMETRICS_ON;
        }
        else {
            this.fmHintValue = RenderingHints.VALUE_FRACTIONALMETRICS_OFF;
        }
    }
    
    public FontRenderContext(AffineTransform tx, Object obj, Object obj2) {
        if (tx != null && !tx.isIdentity()) {
            this.tx = new AffineTransform(tx);
        }
        try {
            if (RenderingHints.KEY_TEXT_ANTIALIASING.isCompatibleValue(obj)) {
                this.aaHintValue = obj;
            }
            else {
                throw new IllegalArgumentException("AA hint:" + obj);
            }
        }
        catch (Exception ex) {
            throw new IllegalArgumentException("AA hint:" + obj);
        }
        try {
            if (RenderingHints.KEY_FRACTIONALMETRICS.isCompatibleValue(obj2)) {
                this.fmHintValue = obj2;
            }
            else {
                throw new IllegalArgumentException("FM hint:" + obj2);
            }
        }
        catch (Exception ex2) {
            throw new IllegalArgumentException("FM hint:" + obj2);
        }
    }
    
    public boolean isTransformed() {
        if (!this.defaulting) {
            return this.tx != null;
        }
        return !this.getTransform().isIdentity();
    }
    
    public int getTransformType() {
        if (!this.defaulting) {
            if (this.tx == null) {
                return 0;
            }
            return this.tx.getType();
        }
        else {
            return this.getTransform().getType();
        }
    }
    
    public AffineTransform getTransform() {
        return (this.tx == null) ? new AffineTransform() : new AffineTransform(this.tx);
    }
    
    public boolean isAntiAliased() {
        return this.aaHintValue != RenderingHints.VALUE_TEXT_ANTIALIAS_OFF && this.aaHintValue != RenderingHints.VALUE_TEXT_ANTIALIAS_DEFAULT;
    }
    
    public boolean usesFractionalMetrics() {
        return this.fmHintValue != RenderingHints.VALUE_FRACTIONALMETRICS_OFF && this.fmHintValue != RenderingHints.VALUE_FRACTIONALMETRICS_DEFAULT;
    }
    
    public Object getAntiAliasingHint() {
        if (this.defaulting) {
            if (this.isAntiAliased()) {
                return RenderingHints.VALUE_TEXT_ANTIALIAS_ON;
            }
            return RenderingHints.VALUE_TEXT_ANTIALIAS_OFF;
        }
        else {
            return this.aaHintValue;
        }
    }
    
    public Object getFractionalMetricsHint() {
        if (this.defaulting) {
            if (this.usesFractionalMetrics()) {
                return RenderingHints.VALUE_FRACTIONALMETRICS_ON;
            }
            return RenderingHints.VALUE_FRACTIONALMETRICS_OFF;
        }
        else {
            return this.fmHintValue;
        }
    }
    
    @Override
    public boolean equals(Object o) {
        try {
            return this.equals((FontRenderContext)o);
        }
        catch (ClassCastException ex) {
            return false;
        }
    }
    
    public boolean equals(FontRenderContext fontRenderContext) {
        if (this == fontRenderContext) {
            return true;
        }
        if (fontRenderContext == null) {
            return false;
        }
        if (!fontRenderContext.defaulting && !this.defaulting) {
            return fontRenderContext.aaHintValue == this.aaHintValue && fontRenderContext.fmHintValue == this.fmHintValue && ((this.tx == null) ? (fontRenderContext.tx == null) : this.tx.equals(fontRenderContext.tx));
        }
        return fontRenderContext.getAntiAliasingHint() == this.getAntiAliasingHint() && fontRenderContext.getFractionalMetricsHint() == this.getFractionalMetricsHint() && fontRenderContext.getTransform().equals(this.getTransform());
    }
    
    @Override
    public int hashCode() {
        int n = (this.tx == null) ? 0 : this.tx.hashCode();
        int n2;
        if (this.defaulting) {
            n2 = n + this.getAntiAliasingHint().hashCode() + this.getFractionalMetricsHint().hashCode();
        }
        else {
            n2 = n + this.aaHintValue.hashCode() + this.fmHintValue.hashCode();
        }
        return n2;
    }
}
